abacusai.code_embeddings — AbacusAI documentation

# abacusai.code_embeddings

## Classes

`CodeEmbeddings` | Code embeddings

## Module Contents

class abacusai.code_embeddings.CodeEmbeddings(client, embeddings=None, chunkingScheme=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Code embeddings

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - embeddings (dict) – A dictionary mapping the file name to its embeddings.

    - chunkingScheme (str) – The scheme used for chunking the embeddings.

  embeddings = None
  chunking_scheme = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict